#pragma once

#include <cstdint>
#include <string>
#include <vector>

#include "CollectionSchema.h"

namespace VectorDB {

/**
 * @brief Collection schema and runtime information returned by MilvusClient::DescribeCollection().
 */
class CollectionDesc {
public:
    /**
     * @brief Collection schema.
     */
    const CollectionSchema& Schema() const;

    /**
     * @brief Set collection schema.
     */
    void SetSchema(const CollectionSchema& schema);

    /**
     * @brief Set collection schema.
     */
    void SetSchema(CollectionSchema&& schema);

    /**
     * @brief Collection id.
     */
    int64_t ID() const;

    /**
     * @brief Set collection id.
     */
    void SetID(int64_t id);

    /**
     * @brief Collection alias.
     */
    const std::vector<std::string>& Alias() const;

    /**
     * @brief Set collection alias.
     */
    void SetAlias(const std::vector<std::string>& alias);

    /**
     * @brief Set collection alias.
     */
    void SetAlias(std::vector<std::string>&& alias);

    /**
     * @brief Timestamp when the collection created.
     */
    uint64_t CreatedTime() const;

    /**
     * @brief Set timestamp when the collection created.
     */
    void SetCreatedTime(uint64_t ts);

private:
    CollectionSchema schema_;
    int64_t collection_id_;
    std::vector<std::string> alias_;
    uint64_t created_utc_timestamp_ = 0;
};

}  // namespace VectorDB
