#pragma once

#include <cstdint>
#include <string>
#include <vector>

namespace VectorDB {

/**
 * @brief ID array, each ID could be int64 type or string type. \n
 * Note: v2.0 only support int64 type id.
 */
class IDArray {
public:
    /**
     * @brief Constructor
     */
    explicit IDArray(const std::vector<int64_t>& id_array);

    /**
     * @brief Constructor
     */
    explicit IDArray(std::vector<int64_t>&& id_array);

    /**
     * @brief Constructor
     */
    explicit IDArray(const std::vector<std::string>& id_array);

    /**
     * @brief Constructor
     */
    explicit IDArray(std::vector<std::string>&& id_array);

    /**
     * @brief Indicate this is an integer id array
     */
    bool IsIntegerID() const;

    /**
     * @brief Return integer id array
     */
    const std::vector<int64_t>& IntIDArray() const;

    /**
     * @brief Return string id array
     */
    const std::vector<std::string>& StrIDArray() const;

private:
    bool is_int_array_{true};
    std::vector<int64_t> int_id_array_;
    std::vector<std::string> str_id_array_;
};

}  // namespace VectorDB
